@@ -4,12 +4,13 @@ tools: stanza
 """
 import logging
 from pathlib import Path
+
 import stanza
 from stanza.utils.conll import CoNLL
 
 
 def get_depd_tree(
-    txt_path: Path,
+    doc: str,
     lg: str,
     stanza_model_path: Path,
     tokenize: bool = True,
@@ -20,27 +21,30 @@ def get_depd_tree(
 
     logging.info(f"generating SUD parse for the input document")
 
-    sents = ""
-    with open(txt_path, "r") as rf:
-        for line in rf:
-            sents += line
-            if tokenize and not ssplit:
-                sents += "\n"
-
     model_dir = str(stanza_model_path)
     if tokenize and ssplit:
-        stanza_nlp = stanza.Pipeline(lang=lg, dir=model_dir, use_gpu=cuda, verbose=verbose)
+        stanza_nlp = stanza.Pipeline(
+            lang=lg, dir=model_dir, use_gpu=cuda, verbose=verbose
+        )
     elif tokenize:
         stanza_nlp = stanza.Pipeline(
-            lang=lg, dir=model_dir, tokenize_no_ssplit=True, use_gpu=cuda, verbose=verbose
+            lang=lg,
+            dir=model_dir,
+            tokenize_no_ssplit=True,
+            use_gpu=cuda,
+            verbose=verbose,
         )
     else:
         stanza_nlp = stanza.Pipeline(
-            lang=lg, dir=model_dir, tokenize_pretokenized=True, use_gpu=cuda, verbose=verbose
+            lang=lg,
+            dir=model_dir,
+            tokenize_pretokenized=True,
+            use_gpu=cuda,
+            verbose=verbose,
         )
 
-    doc = stanza_nlp(sents)
-    doc_dict = doc.to_dict()
+    stanza_doc = stanza_nlp(doc)
+    doc_dict = stanza_doc.to_dict()
     conll = CoNLL.convert_dict(doc_dict)
     doc_conll_str = CoNLL.conll_as_string(conll)
 
