@@ -16,7 +16,14 @@ def visualize_errors(error_tuples: List) -> Tuple[List, List]:
     out_spans = []
     out_depds = []
 
-    for sent, feat, token_idx, token_feat_value, head_token_idx, head_feat_value in error_tuples:
+    for (
+        sent,
+        feat,
+        token_idx,
+        token_feat_value,
+        head_token_idx,
+        head_feat_value,
+    ) in error_tuples:
 
         words = [token.form for token in sent]
 
@@ -97,7 +104,13 @@ def visualize_errors_chau(error_tuples, relation_map) -> Tuple[List, List, List]
         depd_anns = []
         error_types = []
         if isAgreeError:
-            for feat, (_, _, _, token_feat_value, head_feat_value) in agreement_examples_per_rules.items():
+            for feat, (
+                _,
+                _,
+                _,
+                token_feat_value,
+                head_feat_value,
+            ) in agreement_examples_per_rules.items():
                 """depd anns with dependency label and feature values for depd and head tokens"""
                 depd_anns.append(
                     (
@@ -119,7 +132,13 @@ def visualize_errors_chau(error_tuples, relation_map) -> Tuple[List, List, List]
                 )
                 error_types.append(f"wordorder-{feat}")
         if isAssignmentError:
-            for feat, (_, _, _, token_feat_value, expected_label) in casemarking_examples_per_rules.items():
+            for feat, (
+                _,
+                _,
+                _,
+                token_feat_value,
+                expected_label,
+            ) in casemarking_examples_per_rules.items():
                 """depd anns with dependency label and feature values for depd and head tokens"""
                 depd_anns.append(
                     (
@@ -132,7 +151,7 @@ def visualize_errors_chau(error_tuples, relation_map) -> Tuple[List, List, List]
 
         out_depds += [list(format_dep_ascii_markup(sent_tokens, depd_anns))]
 
-    return out_spans, out_depds, error_types
+    return out_spans, out_depds
 
 
 def write_visualizations(file_path: str, spans: List, depds: List):
@@ -178,9 +197,14 @@ def get_conll_str(sent: pyconll.unit.sentence.Sentence, token_id: int) -> str:
 
 def visualize_conll_errors(error_tuples: List):
     conll_str = []
-    for idx, (sent, feat, token_idx, token_feat_value, head_token_idx, head_feat_value) in enumerate(
-        error_tuples
-    ):
+    for idx, (
+        sent,
+        feat,
+        token_idx,
+        token_feat_value,
+        head_token_idx,
+        head_feat_value,
+    ) in enumerate(error_tuples):
         conll_str += [f"<div class='bibtex' id='{idx}'>"]
         conll_str += [get_conll_str(sent, token_idx)]
         conll_str += ["</div>"]
@@ -238,7 +262,9 @@ def visualize_conll_errors_chau(error_tuples, relation_map, lang_id):
                 for erro_feat in erro_feats:
                     prop = erro_feat.split("-")[0].title()
                     pos = erro_feat.split("-")[1]
-                    rule_page = f"{autolex_page}/{lang_id}/Agreement/{prop}/{pos}/{pos}.html"
+                    rule_page = (
+                        f"{autolex_page}/{lang_id}/Agreement/{prop}/{pos}/{pos}.html"
+                    )
                     agreement_conll_strs += [
                         f'<tr> {prop} agreement in {pos} </tr> <tr> <a href="{rule_page}">Click here</a></tr>\n'
                     ]
@@ -271,7 +297,11 @@ def visualize_conll_errors_chau(error_tuples, relation_map, lang_id):
 
             if isAssignmentError:
                 casemarking_examples_per_rules = findWordsWhereMarkingNotFollowed(
-                    assignment_rules_not_followed, sent, sent_tokens, token, relation_map
+                    assignment_rules_not_followed,
+                    sent,
+                    sent_tokens,
+                    token,
+                    relation_map,
                 )
                 erro_feats = list(casemarking_examples_per_rules.keys())
                 casemarking_conll_strs += [
@@ -292,15 +322,23 @@ def visualize_conll_errors_chau(error_tuples, relation_map, lang_id):
         except Exception as e:
             continue
         idx += 1
-    return "\n".join(agreement_conll_strs), "\n".join(wordorder_conll_strs), "\n".join(casemarking_conll_strs)
+    return (
+        "\n".join(agreement_conll_strs),
+        "\n".join(wordorder_conll_strs),
+        "\n".join(casemarking_conll_strs),
+    )
 
 
 def write_html_visualizations(file_path: Path, conll_examples: str):
 
     # load header and footer content
-    with open(f"{Path(__file__).parent.resolve()}/html_templates/header.html", "r") as rf:
+    with open(
+        f"{Path(__file__).parent.resolve()}/html_templates/header.html", "r"
+    ) as rf:
         HEADER = "".join(rf.readlines())
-    with open(f"{Path(__file__).parent.resolve()}/html_templates/footer.html", "r") as rf:
+    with open(
+        f"{Path(__file__).parent.resolve()}/html_templates/footer.html", "r"
+    ) as rf:
         FOOTER = "".join(rf.readlines())
 
     with open(file_path, "w") as wf:
@@ -309,7 +347,9 @@ def write_html_visualizations(file_path: Path, conll_examples: str):
         wf.write(f"{FOOTER}\n")
 
 
-def findWordsWhereAgreementNotFollowed(rules_not_followed, sent, sent_tokens, token, relation_map):
+def findWordsWhereAgreementNotFollowed(
+    rules_not_followed, sent, sent_tokens, token, relation_map
+):
     id2index = sent._ids_to_indexes
     token_num = id2index[token.id]
     token = sent[token_num]
@@ -322,13 +362,19 @@ def findWordsWhereAgreementNotFollowed(rules_not_followed, sent, sent_tokens, to
             sent_example_tokens = deepcopy(sent_tokens)
             token_feature_value = rule_utils.getFeatureValue(model, token.feats)
             sent_example_tokens[token_num] = (
-                "***" + sent_example_tokens[token_num] + f"({model}={token_feature_value})***"
+                "***"
+                + sent_example_tokens[token_num]
+                + f"({model}={token_feature_value})***"
             )
 
             token_head_num = id2index[token.head]
-            headtoken_feature_value = rule_utils.getFeatureValue(model, sent[token.head].feats)
+            headtoken_feature_value = rule_utils.getFeatureValue(
+                model, sent[token.head].feats
+            )
             sent_example_tokens[token_head_num] = (
-                "***" + sent_example_tokens[token_head_num] + f"({model}={headtoken_feature_value})***"
+                "***"
+                + sent_example_tokens[token_head_num]
+                + f"({model}={headtoken_feature_value})***"
             )
 
             # sent_error_examples.append(f'Example: {" ".join(sent_example_tokens)}\n')
@@ -350,7 +396,9 @@ def findWordsWhereAgreementNotFollowed(rules_not_followed, sent, sent_tokens, to
     return rules_per_features
 
 
-def findWordsWhereWordOrderNotFollowed(rules_not_followed, sent, sent_tokens, token, relation_map):
+def findWordsWhereWordOrderNotFollowed(
+    rules_not_followed, sent, sent_tokens, token, relation_map
+):
     id2index = sent._ids_to_indexes
     token_num = id2index[token.id]
     token = sent[token_num]
@@ -369,10 +417,14 @@ def findWordsWhereWordOrderNotFollowed(rules_not_followed, sent, sent_tokens, to
                 not_label = "before"
 
             sent_example_tokens = deepcopy(sent_tokens)
-            sent_example_tokens[token_num] = "***" + sent_example_tokens[token_num] + f"({dep})***"
+            sent_example_tokens[token_num] = (
+                "***" + sent_example_tokens[token_num] + f"({dep})***"
+            )
 
             token_head_num = id2index[token.head]
-            sent_example_tokens[token_head_num] = "***" + sent_example_tokens[token_head_num] + f"({head})***"
+            sent_example_tokens[token_head_num] = (
+                "***" + sent_example_tokens[token_head_num] + f"({head})***"
+            )
 
             # sent_error_examples.append(f'Example: {" ".join(sent_example_tokens)}\n')
             # sent_error_examples.append(
@@ -382,11 +434,19 @@ def findWordsWhereWordOrderNotFollowed(rules_not_followed, sent, sent_tokens, to
             active_text, nonactive_text = getActiveFeatures(
                 one_active, one_nonactive, "wordorder", model, relation_map
             )
-            rules_per_features[model] = (sent_example_tokens, active_text, nonactive_text, None, None)
+            rules_per_features[model] = (
+                sent_example_tokens,
+                active_text,
+                nonactive_text,
+                None,
+                None,
+            )
     return rules_per_features
 
 
-def findWordsWhereMarkingNotFollowed(rules_not_followed, sent, sent_tokens, token, relation_map):
+def findWordsWhereMarkingNotFollowed(
+    rules_not_followed, sent, sent_tokens, token, relation_map
+):
     id2index = sent._ids_to_indexes
     token_num = id2index[token.id]
     token = sent[token_num]
@@ -399,7 +459,9 @@ def findWordsWhereMarkingNotFollowed(rules_not_followed, sent, sent_tokens, toke
             sent_example_tokens = deepcopy(sent_tokens)
             value = rule_utils.getFeatureValue("Case", token.feats)
             sent_example_tokens[token_num] = (
-                "***" + sent_example_tokens[token_num] + f"({token.upos}'s Case={value})***"
+                "***"
+                + sent_example_tokens[token_num]
+                + f"({token.upos}'s Case={value})***"
             )
 
             # sent_error_examples.append(f'Example: {" ".join(sent_example_tokens)}\n')
@@ -410,19 +472,30 @@ def findWordsWhereMarkingNotFollowed(rules_not_followed, sent, sent_tokens, toke
             active_text, nonactive_text = getActiveFeatures(
                 one_active, one_nonactive, "assignment", model, relation_map
             )
-            rules_per_features[model] = (sent_example_tokens, active_text, nonactive_text, value, label)
+            rules_per_features[model] = (
+                sent_example_tokens,
+                active_text,
+                nonactive_text,
+                value,
+                label,
+            )
 
     return rules_per_features
 
 
 def getActiveFeatures(active, non_active, task, model, relation_map):
-    active_text, nonactive_text = "Required Active features in the rule:\n", "Not Active:"
+    active_text, nonactive_text = (
+        "Required Active features in the rule:\n",
+        "Not Active:",
+    )
     if len(active) > 0:
         covered_act = set()
         for a in active:
             if a in covered_act:
                 continue
-            active_human = rule_utils.transformRulesIntoReadable(a, task, model, relation_map)
+            active_human = rule_utils.transformRulesIntoReadable(
+                a, task, model, relation_map
+            )
             covered_act.add(a)
             active_text += active_human + "\n"
 
@@ -431,7 +504,9 @@ def getActiveFeatures(active, non_active, task, model, relation_map):
         for n in non_active:
             if n in covered_na or n:
                 continue
-            nonactive_human = rule_utils.transformRulesIntoReadable(n, task, model, relation_map)
+            nonactive_human = rule_utils.transformRulesIntoReadable(
+                n, task, model, relation_map
+            )
             covered_na.add(n)
             nonactive_text += nonactive_human + "\n"
 
